package com.fq.channel.sdk;

import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

public class MyDialog extends Dialog{

	public MyDialog(Context context) {
		super(context);
	}

	private Button yes;//确定按钮
    private Button no;//否定按钮
    private Button cancel; //取消按钮

    private TextView titleTv;//消息标题文本
    private TextView messageTv;//消息提示文本
    private String titleStr;//从外界设置的title文本
    private String messageStr;//从外界设置的消息文本

    //确定文本和取消文本的显示内容
    private String yesStr, noStr,cancelStr;

    private YesOnclickListener yesOnclickListener;//确定按钮被点击了的监听器
    private NoOnclickListener noOnclickListener;//否定按钮被点击了的监听器
    private CancelOnclickListener cancelOnclickListener; //取消按钮被点击了的监听器

    /**
     * 设置确定按钮的显示内容和监听
     *
     * @param str
     * @param onYesOnclickListener
     */
    public void setYesOnclickListener(String str, YesOnclickListener yesOnclickListener2) {
        if (str != null) {
            yesStr = str;
        }
        this.yesOnclickListener = yesOnclickListener2;
    }

    /**
     * 设置否定按钮的显示内容和监听
     *
     * @param str
     * @param onNoOnclickListener
     */
    public void setNoOnclickListener(String str, NoOnclickListener noOnclickListener) {
        if (str != null) {
            noStr = str;
        }
        this.noOnclickListener = noOnclickListener;
    }

    /**
     * 设置取消按钮的显示内容和监听
     *
     * @param str
     * @param onNoOnclickListener
     */
    public void setCancelOnclickListener(String str, CancelOnclickListener cancelOnclickListener) {
        if (str != null) {
        	cancelStr = str;
        }
        this.cancelOnclickListener = cancelOnclickListener;
    }

    /**
     * 为Dialog设置标题
     * @param title
     */
    public void setTitle(String title) {
        titleStr = title;
    }

    /**
     * 为Dialog设置dialog的message
     * @param message
     */
    public void setMessage(String message) {
        messageStr = message;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

//        setContentView(R.layout.mydialog);

        //为适应打包系统，打出母包jar  不能通过R文件来调用
        LayoutInflater inflater = LayoutInflater.from(getContext());
        View view = inflater.inflate(getContext().getResources().getIdentifier("mydialog", "layout", getContext().getPackageName()), null);
        setContentView(view);

        yes = (Button) findViewById(getContext().getResources().getIdentifier("yes", "id", getContext().getPackageName()));
        no = (Button) findViewById(getContext().getResources().getIdentifier("no", "id", getContext().getPackageName()));
        cancel = (Button) findViewById(getContext().getResources().getIdentifier("cancel", "id", getContext().getPackageName()));

        titleTv = (TextView) findViewById(getContext().getResources().getIdentifier("title", "id", getContext().getPackageName()));
        messageTv = (TextView) findViewById(getContext().getResources().getIdentifier("message", "id", getContext().getPackageName()));

        //按空白处不能取消动画
        setCanceledOnTouchOutside(false);


//        //初始化界面控件
//        initView();
        //初始化界面数据
        initData();
        //初始化界面控件的事件
        initEvent();

    }

//    /**
//     * 初始化界面控件
//     */
//    private void initView() {
//        yes = (Button) findViewById(R.id.yes);
//        no = (Button) findViewById(R.id.no);
//        cancel = (Button) findViewById(R.id.cancel);
//
//        titleTv = (TextView) findViewById(R.id.title);
//        messageTv = (TextView) findViewById(R.id.message);
//    }


    /**
     * 初始化界面控件的显示数据
     */
    private void initData() {
        //如果用户自定了title和message
        if (titleStr != null) {
            titleTv.setText(titleStr);
        }
        if (messageStr != null) {
            messageTv.setText(messageStr);
        }
        //如果设置按钮的文字
        if (yesStr != null) {
            yes.setText(yesStr);
        }
        if (noStr != null) {
            no.setText(noStr);
        }
        if (cancelStr != null) {
            cancel.setText(cancelStr);
        }
    }

    /**
     * 初始化界面的确定和取消监听器
     */
    private void initEvent() {

        //设置确定按钮被点击后，向外界提供监听
        yes.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (yesOnclickListener != null) {
                	yesOnclickListener.YesOnClick();
                }
            }
        });

        //设置否定按钮被点击后，向外界提供监听
        no.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (noOnclickListener != null) {
                    noOnclickListener.NoOnClick();
                }
            }
        });

        //设置取消按钮被点击后，向外界提供监听
        cancel.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				if (cancelOnclickListener != null) {
					cancelOnclickListener.CancelOnClick();
				}
			}
		});

    }


    /**
     * 设置确定按钮、否定和取消被点击的接口
     */
    public interface YesOnclickListener {
        public void YesOnClick();
    }

    public interface NoOnclickListener {
        public void NoOnClick();
    }

    public interface CancelOnclickListener{
    	public void CancelOnClick();
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == KeyEvent.KEYCODE_BACK) {
        	if (cancelOnclickListener != null) {
				cancelOnclickListener.CancelOnClick();
			}
        	return true;
        }

        return false;
    }
}




